(colab)=

# Google Colab Notebooks

Here are some Google Colab notebooks that demonstrate how to use LightlyTrain with various packages. You can run these notebooks directly in Google Colab to see how LightlyTrain works in practice.

- [Ultralytics](https://colab.research.google.com/github/lightly-ai/lightly-train/blob/main/examples/notebooks/ultralytics_yolo.ipynb)
- [YOLOv12](https://colab.research.google.com/github/lightly-ai/lightly-train/blob/main/examples/notebooks/yolov12.ipynb)
- [RF-DETR](https://colab.research.google.com/github/lightly-ai/lightly-train/blob/main/examples/notebooks/rfdetr.ipynb)
